//---------------------------------------------------------------------------
// Pivot Points
//---------------------------------------------------------------------------
library PivotPoints;

uses
  SysUtils, classes, graphics, math,
  IndicatorInterfaceUnit,
  TechnicalFunctions in 'TechnicalFunctions.pas';

var
  Continuous: boolean;
  

  // index buffers
  PP, R1, S1: TIndexBuffer;


//---------------------------------------------------------------------------
// Initialization
//---------------------------------------------------------------------------
procedure Init; stdcall;
begin
  // define parameters
  IndicatorShortName('Pivot Points');
  SetOutputWindow(ow_ChartWindow);

  RegOption('Continuous', ot_Boolean, Continuous);
  Continuous := false;

  

  // create index buffers
  PP := CreateIndexBuffer;
  R1 := CreateIndexBuffer;
  S1 := CreateIndexBuffer;

  IndicatorBuffers(3);


  SetIndexBuffer(0, R1);
  SetIndexStyle(0, ds_Line, psDot, 1, clRed);
  SetIndexLabel(0, 'R1');

  SetIndexBuffer(1, PP);
  SetIndexStyle(1, ds_Line, psDot, 1, clMaroon);
  SetIndexLabel(1, 'PP');

  SetIndexBuffer(2, S1);
  SetIndexStyle(2, ds_Line, psDot, 1, clRed);
  SetIndexLabel(2, 'S1');



end;

//---------------------------------------------------------------------------
// Deinitialization
//---------------------------------------------------------------------------
procedure Done; stdcall;
begin
  //
end;

//---------------------------------------------------------------------------
// Calculate bar
//---------------------------------------------------------------------------
procedure Calculate(index: integer); stdcall;
var
  day, i: integer;
  h, l, c, _pp, _R1, _S1: double;
begin
  if TimeFrame > PERIOD_H4 then
    exit;

  day := trunc(Time(index));
  if trunc(Time(Bars - 1)) >= day then
    exit;

  if trunc(Time(index + 1)) = day then
    begin
      PP[index] := PP[index + 1];
      R1[index] := R1[index + 1];
      S1[index] := S1[index + 1];
            
      exit;
    end;

  if not(Continuous) then
    begin
      PP[index + 1] := 0;
      R1[index + 1] := 0;
      S1[index + 1] := 0;
      
    end;

  i := index + 1;
  day := trunc(Time(i));

  h := High(i);
  l := Low(i);
  c := Close(i);
  inc(i);

  while (trunc(Time(i)) = day) and (i < Bars) do
    begin
      h := Max(High(i), h);
      l := Min(Low(i), l);
      inc(i);
    end;

  _pp := (h + l )/2;
  _R1 := l;
  _S1 := h;

  PP[index] := _pp;
  R1[index] := _R1;
  S1[index] := _S1;

    end;
end;

exports

Init, Done, Calculate;

end.


